# dunderdoc
Documentation module for all python dunder (magic) methods

## Usage

```bash
uvx dunderdoc print
uvx dunderdoc find __add__  # search by dunder name
uvx dunderdoc list  # show all sections
uvx dunderdoc print {section}  # show all in a section
```

## Installing
If you prefer a persistent install:
```bash
pip install dunderdoc
```